@@ -1,37 +1,44 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2011-2012 Andreas Rönnquist
+ *	Copyright (C) 2011-2013 Andreas Rönnquist
  *
- *	devilspie2 is free software: you can redistribute it and/or 
- *	modify it under the terms of the GNU General Public License as published 
+ *	devilspie2 is free software: you can redistribute it and/or
+ *	modify it under the terms of the GNU General Public License as published
  *	by the Free Software Foundation, either version 3 of the License, or
  *	(at your option) any later version.
- * 
+ *
  *	devilspie2 is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *	GNU General Public License for more details.
- * 
+ *
  *	You should have received a copy of the GNU General Public License
- *	along with devilspie2.  
+ *	along with devilspie2.
  *	If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef __HEADER_SCRIPT_
 #define __HEADER_SCRIPT_
 
+/**
+ *
+ */
+
 
 /**
  *
  */
-void init_script();
-void done_script();
+lua_State *init_script();
 
-void register_cfunctions();
+void register_cfunctions(lua_State *lua);
+int load_script(lua_State *lua,char *filename);
+
+void run_script(lua_State *lua);
+void done_script(lua_State *lua);
 
-void run_script();
-int load_script(char *filename);
 
 extern gboolean devilspie2_debug;
 extern gboolean devilspie2_emulate;
 
+extern lua_State *global_lua_state;
+
 #endif /*__HEADER_SCRIPT_*/
